@@ -45,11 +45,11 @@ class Storage(driver.Base):
         
         return object_instance.generate_url("GET")
     
-    def get_json(self, path):
-        try:
-            return json.loads(self.get_unicode(path) )
-        except:
-            return []
+#    def get_json(self, path):
+#        try:
+#            return json.loads(self.get_unicode(path) )
+#        except:
+#            return []
     @lru.get
     def get_content(self, path):
         logger.info("get_content path:%s" % path)
